package Locale::CLDR::Locales::En::Any;

# This file auto generated
#	on Fri 19 Dec  1:38:47 am GMT

use version;

our $VERSION = version->declare('v0.26.4');

use v5.10;
use mro 'c3';
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moose;

extends('Locale::CLDR::Locales::En');

no Moose;
__PACKAGE__->meta->make_immutable;
